@@ -10,10 +10,10 @@ else:
 if hasattr(asyncio, 'all_tasks'):
     all_tasks = asyncio.all_tasks
 else:
-    all_tasks = asyncio.Task.all_tasks
+    all_tasks = asyncio.Task.all_tasks  # type: ignore
 
 
 if hasattr(asyncio, 'current_task'):
     current_task = asyncio.current_task
 else:
-    current_task = asyncio.Task.current_task
+    current_task = asyncio.Task.current_task  # type: ignore
